Index: dokuwiki/conf/local.php
===================================================================
--- /dev/null	1970-01-01 00:00:00.000000000 +0000
+++ dokuwiki/conf/local.php	2008-03-26 15:23:05.000000000 +0000
@@ -0,0 +1,133 @@
+<?php
+/*
+ * ©2008 HRMills
+ * This is the global configuration file for lug.org.uk's DokuWiki installation.
+ * Per-site configuration files should be identified, parsed and implemented here.
+ */
+
+$local_group_name = getenv("WIKI_NAME");
+
+$conf['title'] = $local_group_name;
+$conf['lang'] = 'en';
+$conf['useacl'] = 1;
+$conf['superuser'] = '@admin';
+
+$conf['fmode'] = 0664;         // Create files group-writable
+$conf['dmode'] = 0775;
+
+$conf['baseurl'] = 'http://'.$local_group_name.'.lug.org.uk';
+$conf['basedir'] = '/wiki/';
+$conf['savedir'] = getenv("WIKI_DATA");
+
+$conf['mailfrom'] = $local_group_name.'@lug.org.uk';
+
+// Now go and find the dokuwiki configuration file and parse it
+$permitted_config_vars = array('start' => 'nospace',
+			       'title' => 'string',
+			       'lang' => 'nospace',
+			       'recent' => 'int',
+			       'breadcrumbs' => 'int',
+			       'youarehere' => 'bool',
+			       'typography' => 'int|0-2',
+			       'dformat' => 'string',
+			       'signature' => 'string',
+			       'camelcase' => 'bool',
+			       'mailguard' => 'string|visible|hex|none',
+			       'useacl' => 'bool',
+			       'autopasswd' => 'bool',
+			       'superuser' => 'string',
+			       'manager' => 'string',
+			       'profileconfirm' => 'string',
+			       'disableactions' => 'nospace',
+			       'auth_security_timeout' => 'int|1-86400',
+			       'userewrite' => 'int|0-1',
+			       'useslash' => 'bool'
+			       );
+
+$config_file = @fopen(getenv("WIKI_DATA")."../dokuwiki.conf", "r");
+if($config_file != FALSE)
+{
+    while(!feof($config_file))
+    {
+	$line = fgets($config_file);
+	$line = trim($line);
+
+	if(substr($line, 0, 1) == '#')
+	{ continue; } // Skip comment lines
+
+	if(strlen($line) == 0)
+	{ continue; } // Skip lines with only whitespace
+
+	$split_line = explode("=", $line, 2);
+
+	if(count($split_line) != 2)
+	{ continue; } // FIXME: Report a malformed-line error if true here
+
+	$directive = trim($split_line[0]);
+	$data = trim($split_line[1]);
+
+	if(!array_key_exists($directive, $permitted_config_vars))
+	{ continue; } // Do nothing if the directive wasn't in our list
+
+	// Now parse the data appropriately
+	$ranges = explode("|", $permitted_config_vars[$directive]);
+	$type = array_shift($ranges);
+
+	switch($type)
+	{
+	 case 'nospace':
+	    if(preg_match("/[[:space:]]/", $data) == 1)
+	    { continue 2; } // Do nothing if the string contains whitespace
+	    // Fall through to normal string handling
+
+	 case 'string':
+	    // Check for valid ranges
+	    $valid = 0;
+	    foreach($ranges as $r)
+	    {
+		if($data == $r)
+		{
+		    $valid = 1;
+		    break;
+		}
+	    }
+
+	    if($valid == 0 && count($ranges) > 0)
+	    { continue 2; }
+
+	    break;
+
+	 case 'bool':
+	    if($data != "0" && $data != "1")
+	    { continue 2; } // Do nothing if the string isn't 0 or 1
+	    break;
+
+	 case 'int':
+	    if(preg_match("/[^[:digit:]]/", $data) == 1)
+	    { continue 2; } // Do nothing if the string contains non-digits
+
+	    // Check for valid ranges
+	    $valid = 0;
+	    foreach($ranges as $r)
+	    {
+		$minmax = explode("-", $r);
+		if($data >= $minmax[0] && $data <= $minmax[1])
+		{
+		    $valid = 1;
+		    break;
+		}
+	    }
+
+	    if($valid == 0 && count($ranges) > 0)
+	    { continue 2; }
+
+	    break;
+	}
+
+	// Now we've validated/cleaned the input, set the parameter
+	$conf[$directive] = $data;
+    }
+    fclose($config_file);
+}
+
+?>
